package cz.muni.fi.lasaris.sbms.data;

import java.util.Properties;

import org.apache.log4j.Logger;

import cz.muni.fi.lasaris.sbms.data.connectors.ArchiveConnector;
import cz.muni.fi.lasaris.sbms.data.connectors.BASConnector;


public class ConnectorProvider {
	final static Logger logger = Logger.getLogger(ConnectorProvider.class);
	private static ArchiveConnector aConnector;
	private static BASConnector bConnector;
	
	public static void init(Properties props) {
		try {
			String bClassName = props.getProperty("data.connectors.bas");
			String aClassName = props.getProperty("data.connectors.archive");
			if(bClassName != null) {
				Class<?> c = Class.forName(bClassName);
				ConnectorProvider.bConnector = (BASConnector)c.newInstance();
				ConnectorProvider.bConnector.init(props);
				logger.debug("BAS connector initialized.");
			} else {
				throw new IllegalArgumentException("Unable to initialize BAS data provider.");
			}
			if(aClassName != null) {
				Class<?> c = Class.forName(aClassName);
				ConnectorProvider.aConnector = (ArchiveConnector)c.newInstance();
				ConnectorProvider.aConnector.init(props);
				logger.debug("Archive connector initialized.");
			} else {
				throw new IllegalArgumentException("Unable to initialize Archive data provider.");
			}
		} catch (Exception ex) {
			logger.error("Unable to initialize data providers.");
			logger.error(ex);
		}
	}
	
	public static BASConnector getBASConnector() {
		if(ConnectorProvider.bConnector == null) {
			throw new IllegalStateException("connector not set");
		}
		return ConnectorProvider.bConnector;
	}
	
	public static ArchiveConnector getArchiveConnector() {
		if(ConnectorProvider.aConnector == null) {
			throw new IllegalStateException("connector not set");
		}
		return ConnectorProvider.aConnector;
	}
}
